@@ -106,6 +106,13 @@ Qt::ItemFlags FolderStatusModel::flags(const QModelIndex &index) const
     if (!_accountState) {
         return nullptr;
     }
+
+    auto flags = Qt::ItemIsEnabled;
+    if (_folders.size() > index.row()) {
+        const SubFolderInfo &folderInfo = _folders.at(index.row());
+        flags = folderInfo._folder->isReady() ? Qt::ItemIsEnabled : Qt::NoItemFlags;
+    }
+
     switch (classify(index)) {
     case AddButton: {
         Qt::ItemFlags ret;
@@ -113,16 +120,16 @@ Qt::ItemFlags FolderStatusModel::flags(const QModelIndex &index) const
         if (!_accountState->isConnected()) {
             return ret;
         }
-        return Qt::ItemIsEnabled | ret;
+        return flags | ret;
     }
     case FetchLabel:
-        return Qt::ItemIsEnabled | Qt::ItemNeverHasChildren;
+        return flags | Qt::ItemNeverHasChildren;
     case RootFolder:
-        return Qt::ItemIsEnabled;
+        return flags;
     case SubFolder:
-        return Qt::ItemIsEnabled | Qt::ItemIsUserCheckable | Qt::ItemIsSelectable;
+        return flags | Qt::ItemIsUserCheckable | Qt::ItemIsSelectable;
     }
-    return nullptr;
+    return Qt::NoItemFlags;
 }
 
 QVariant FolderStatusModel::data(const QModelIndex &index, int role) const
@@ -217,7 +224,7 @@ QVariant FolderStatusModel::data(const QModelIndex &index, int role) const
         return errors;
     }
     case FolderStatusDelegate::FolderInfoMsg:
-        return f->virtualFilesEnabled() && f->vfs().mode() != Vfs::Mode::WindowsCfApi
+        return f->isReady() && f->virtualFilesEnabled() && f->vfs().mode() != Vfs::Mode::WindowsCfApi
             ? QStringList(tr("Virtual file support is enabled."))
             : QStringList();
     case FolderStatusDelegate::SyncRunning:
@@ -535,7 +542,7 @@ bool FolderStatusModel::canFetchMore(const QModelIndex &parent) const
         // Keep showing the error to the user, it will be hidden when the account reconnects
         return false;
     }
-    if (info->_folder && !info->_folder->supportsSelectiveSync()) {
+    if (info->_folder && info->_folder->isReady() && !info->_folder->supportsSelectiveSync()) {
         // Selective sync is hidden in that case
         return false;
     }
@@ -834,7 +841,7 @@ void FolderStatusModel::slotApplySelectiveSync()
         // do the sync if there were changes
         const auto changes = (oldBlackListSet - blackListSet) + (blackListSet - oldBlackListSet);
         if (!changes.isEmpty()) {
-            if (folder->isBusy()) {
+            if (folder->isSyncRunning()) {
                 folder->slotTerminateSync();
             }
             //The part that changed should not be read from the DB on next sync because there might be new folders
@@ -1147,7 +1154,7 @@ void FolderStatusModel::slotSyncAllPendingBigFolders()
         folder->journalDb()->setSelectiveSyncList(SyncJournalDb::SelectiveSyncUndecidedList, QStringList());
 
         // Trigger a sync
-        if (folder->isBusy()) {
+        if (folder->isSyncRunning()) {
             folder->slotTerminateSync();
         }
         // The part that changed should not be read from the DB on next sync because there might be new folders
