@@ -30,21 +30,23 @@
 #include "protocolwidget.h"
 #include "owncloudsetupwizard.h"
 
-#include <QLabel>
-#include <QStandardItemModel>
-#include <QStackedWidget>
-#include <QPushButton>
-#include <QSettings>
-#include <QToolBar>
-#include <QToolButton>
-#include <QLayout>
-#include <QVBoxLayout>
-#include <QPixmap>
 #include <QImage>
-#include <QWidgetAction>
+#include <QLabel>
+#include <QLayout>
+#include <QMessageBox>
 #include <QPainter>
 #include <QPainterPath>
-#include <QMessageBox>
+#include <QPixmap>
+#include <QPushButton>
+#include <QScreen>
+#include <QSettings>
+#include <QStackedWidget>
+#include <QStandardItemModel>
+#include <QToolBar>
+#include <QToolButton>
+#include <QVBoxLayout>
+#include <QWidgetAction>
+#include <QWindow>
 
 #ifdef Q_OS_MAC
 #include "settingsdialog_mac.h"
@@ -53,6 +55,26 @@ void setActivationPolicy(ActivationPolicy policy);
 #endif
 
 namespace {
+auto minimumSizeHint(const QWidget *w)
+{
+    const QSize min { 800, 700 }; // When changing this, please check macOS: widgets there have larger insets, so they take up more space.
+    const auto screen = w->windowHandle() ? w->windowHandle()->screen() : QApplication::screenAt(QCursor::pos());
+    if (screen) {
+        const auto availableSize = screen->availableSize();
+        if (availableSize.isValid()) {
+            // Assume we can use at least 90% of the screen, if the screen is smaller than 800x700 pixels.
+            //
+            // Note: this means that the wizards have even less space: with the style we use, the
+            // wizard tries to fit inside the window. So, if this is a common case that users have
+            // such small screens, and the contents of the wizard screen are squashed together (or
+            // not shown due to lack of space), we should consider putting that content in a
+            // scroll-view.
+            return min.boundedTo(availableSize * 0.9);
+        }
+    }
+    return min;
+}
+
 const QString TOOLBAR_CSS()
 {
     return QStringLiteral("QToolBar { background: %1; margin: 0; padding: 0; border: none; border-bottom: 1px solid %2; spacing: 0; } "
@@ -206,11 +228,13 @@ SettingsDialog::SettingsDialog(ownCloudGui *gui, QWidget *parent)
     spacer->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
     _ui->toolBar->addWidget(spacer);
 
-    QAction *quitAction = createActionWithIcon(QStringLiteral("quit"), tr("Quit %1").arg(qApp->applicationName()));
+    const auto appNameGui = Theme::instance()->appNameGUI();
+
+    QAction *quitAction = createActionWithIcon(QStringLiteral("quit"), tr("Quit %1").arg(appNameGui));
     quitAction->setCheckable(false);
-    connect(quitAction, &QAction::triggered, this, [this] {
-        const auto reply = QMessageBox::question(this, tr("Quit %1").arg(qApp->applicationName()),
-            tr("Are you sure you want to quit %1?").arg(qApp->applicationName()),
+    connect(quitAction, &QAction::triggered, this, [this, appNameGui] {
+        const auto reply = QMessageBox::question(this, tr("Quit %1").arg(appNameGui),
+            tr("Are you sure you want to quit %1?").arg(appNameGui),
             QMessageBox::Yes | QMessageBox::No);
         if (reply == QMessageBox::Yes) {
             qApp->quit();
@@ -227,7 +251,7 @@ SettingsDialog::SettingsDialog(ownCloudGui *gui, QWidget *parent)
         this, &SettingsDialog::accountAdded);
     connect(AccountManager::instance(), &AccountManager::accountRemoved,
         this, &SettingsDialog::accountRemoved);
-    foreach (auto ai, AccountManager::instance()->accounts()) {
+    for (const auto &ai : AccountManager::instance()->accounts()) {
         accountAdded(ai.data());
     }
 
@@ -248,11 +272,7 @@ SettingsDialog::SettingsDialog(ownCloudGui *gui, QWidget *parent)
     customizeStyle();
 
     cfg.restoreGeometry(this);
-    if (size().width() < minimumSizeHint().width() || size().height() < minimumSizeHint().height())
-    {
-        resize(minimumSizeHint());
-    }
-
+    setMinimumSize(::minimumSizeHint(this));
 #ifdef Q_OS_MAC
     setActivationPolicy(ActivationPolicy::Accessory);
 #endif
@@ -263,9 +283,9 @@ SettingsDialog::~SettingsDialog()
     delete _ui;
 }
 
-QSize SettingsDialog::minimumSizeHint() const
+QSize SettingsDialog::sizeHintForChild() const
 {
-    return {800, 500};
+    return ::minimumSizeHint(this) * 0.9;
 }
 
 QWidget* SettingsDialog::currentPage()
@@ -273,7 +293,6 @@ QWidget* SettingsDialog::currentPage()
     return _ui->stack->currentWidget();
 }
 
-
 void SettingsDialog::changeEvent(QEvent *e)
 {
     switch (e->type()) {
@@ -327,12 +346,12 @@ void SettingsDialog::showActivityPage()
     }
 }
 
-void SettingsDialog::showIssuesList(const QString &folderAlias)
+void SettingsDialog::showIssuesList()
 {
     if (!_activityAction)
         return;
     _activityAction->trigger();
-    _activitySettings->slotShowIssuesTab(folderAlias);
+    _activitySettings->slotShowIssuesTab();
 }
 
 void SettingsDialog::accountAdded(AccountState *s)
@@ -441,7 +460,8 @@ void SettingsDialog::customizeStyle()
     QString background(palette().base().color().name());
     _ui->toolBar->setStyleSheet(TOOLBAR_CSS().arg(background, dark, highlightColor, highlightTextColor));
 
-    for (auto a : findChildren<ToolButtonAction *>()) {
+    const auto &toolButtonActions = findChildren<ToolButtonAction *>();
+    for (auto *a : toolButtonActions) {
         a->updateIcon();
     }
 }
