@@ -92,9 +92,9 @@ ShareUserGroupWidget::ShareUserGroupWidget(AccountPtr account,
 
     // By making the next two QueuedConnections we can override
     // the strings the completer sets on the line edit.
-    connect(_completer, SIGNAL(activated(QModelIndex)), SLOT(slotCompleterActivated(QModelIndex)),
+    connect(_completer, qOverload<const QModelIndex &>(&QCompleter::activated), this, &ShareUserGroupWidget::slotCompleterActivated,
         Qt::QueuedConnection);
-    connect(_completer, SIGNAL(highlighted(QModelIndex)), SLOT(slotCompleterHighlighted(QModelIndex)),
+    connect(_completer, qOverload<const QModelIndex &>(&QCompleter::highlighted), this, &ShareUserGroupWidget::slotCompleterHighlighted,
         Qt::QueuedConnection);
 
     // Queued connection so this signal is recieved after textChanged
@@ -164,7 +164,8 @@ void ShareUserGroupWidget::searchForSharees()
     QSharedPointer<Sharee> currentUser(new Sharee(_account->credentials()->user(), "", Sharee::Type::User));
     blacklist << currentUser;
 
-    foreach (auto sw, _ui->scrollArea->findChildren<ShareUserLine *>()) {
+    const auto &shareUserLines = _ui->scrollArea->findChildren<ShareUserLine *>();
+    for (auto *sw : shareUserLines) {
         blacklist << sw->share()->getShareWith();
     }
     _ui->errorLabel->hide();
@@ -188,7 +189,7 @@ void ShareUserGroupWidget::slotSharesFetched(const QList<QSharedPointer<Share>>
     QSize minimumSize = newViewPort->sizeHint();
     int x = 0;
 
-    foreach (const auto &share, shares) {
+    for (const auto &share : shares) {
         // We don't handle link shares
         if (share->getShareType() == Share::TypeLink) {
             continue;
@@ -240,11 +241,11 @@ void ShareUserGroupWidget::slotPrivateLinkShare()
     menu->setAttribute(Qt::WA_DeleteOnClose);
 
     menu->addAction(tr("Open link in browser"),
-        this, SLOT(slotPrivateLinkOpenBrowser()));
+        this, &ShareUserGroupWidget::slotPrivateLinkOpenBrowser);
     menu->addAction(tr("Copy link to clipboard"),
-        this, SLOT(slotPrivateLinkCopy()));
+        this, &ShareUserGroupWidget::slotPrivateLinkCopy);
     menu->addAction(tr("Send link by email"),
-        this, SLOT(slotPrivateLinkEmail()));
+        this, &ShareUserGroupWidget::slotPrivateLinkEmail);
 
     menu->exec(QCursor::pos());
 }
@@ -320,9 +321,7 @@ void ShareUserGroupWidget::displayError(int code, const QString &message)
     _pi_sharee.stopAnimation();
 
     // Also remove the spinner in the widget list, if any
-    foreach (auto pi, _ui->scrollArea->findChildren<QProgressIndicator *>()) {
-        delete pi;
-    }
+    qDeleteAll(_ui->scrollArea->findChildren<QProgressIndicator *>());
 
     qCWarning(lcSharing) << "Sharing error from server" << code << message;
     _ui->errorLabel->setText(message);
@@ -564,7 +563,7 @@ void ShareUserLine::slotDeleteAnimationFinished()
     // There is a painting bug where a small line of this widget isn't
     // properly cleared. This explicit repaint() call makes sure any trace of
     // the share widget is removed once it's destroyed. #4189
-    connect(this, SIGNAL(destroyed(QObject *)), parentWidget(), SLOT(repaint()));
+    connect(this, &ShareUserLine::destroyed, parentWidget(), qOverload<>(&QWidget::repaint));
 }
 
 void ShareUserLine::slotShareDeleted()
