@@ -93,10 +93,6 @@ void RequestEtagJob::start()
     buf->open(QIODevice::ReadOnly);
     // assumes ownership
     sendRequest("PROPFIND", makeDavUrl(path()), req, buf);
-
-    if (reply()->error() != QNetworkReply::NoError) {
-        qCWarning(lcEtagJob) << "request network error: " << reply()->errorString();
-    }
     AbstractNetworkJob::start();
 }
 
@@ -110,7 +106,7 @@ bool RequestEtagJob::finished()
         // Parse DAV response
         QXmlStreamReader reader(reply());
         reader.addExtraNamespaceDeclaration(QXmlStreamNamespaceDeclaration(QStringLiteral("d"), QStringLiteral("DAV:")));
-        QString etag;
+        QByteArray etag;
         while (!reader.atEnd()) {
             QXmlStreamReader::TokenType type = reader.readNext();
             if (type == QXmlStreamReader::StartElement && reader.namespaceUri() == QLatin1String("DAV:")) {
@@ -119,14 +115,14 @@ bool RequestEtagJob::finished()
                     auto etagText = reader.readElementText();
                     auto parsedTag = parseEtag(etagText.toUtf8());
                     if (!parsedTag.isEmpty()) {
-                        etag += QString::fromUtf8(parsedTag);
+                        etag += parsedTag;
                     } else {
-                        etag += etagText;
+                        etag += etagText.toUtf8();
                     }
                 }
             }
         }
-        emit etagRetreived(etag);
+        emit etagRetreived(etag, QDateTime::fromString(QString::fromUtf8(_responseTimestamp), Qt::RFC2822Date));
         emit finishedWithResult(etag);
     } else {
         emit finishedWithResult(HttpError{ httpCode, errorString() });
@@ -172,7 +168,11 @@ bool MkColJob::finished()
     qCInfo(lcMkColJob) << "MKCOL of" << reply()->request().url() << "FINISHED WITH STATUS"
                        << replyStatusString();
 
-    emit finished(reply()->error());
+    if (reply()->error() != QNetworkReply::NoError) {
+        Q_EMIT finishedWithError(reply());
+    } else {
+        Q_EMIT finishedWithoutError();
+    }
     return true;
 }
 
@@ -282,9 +282,8 @@ bool LsColXMLParser::parse(const QByteArray &xml, QHash<QString, qint64> *sizes,
                 } else if (reader.name() == QLatin1String("propstat")) {
                     insidePropstat = false;
                     if (currentPropsHaveHttp200) {
-                        currentHttp200Properties = QMap<QString, QString>(currentTmpProperties);
+                        currentHttp200Properties = std::move(currentTmpProperties);
                     }
-                    currentTmpProperties.clear();
                     currentPropsHaveHttp200 = false;
                 } else if (reader.name() == QLatin1String("prop")) {
                     insideProp = false;
@@ -310,7 +309,8 @@ bool LsColXMLParser::parse(const QByteArray &xml, QHash<QString, qint64> *sizes,
 /*********************************************************************************************/
 
 LsColJob::LsColJob(AccountPtr account, const QString &path, QObject *parent)
-    : AbstractNetworkJob(account, path, parent)
+    : AbstractNetworkJob(account, QString(), parent)
+    , _url(makeDavUrl(path))
 {
 }
 
@@ -320,7 +320,7 @@ LsColJob::LsColJob(AccountPtr account, const QUrl &url, QObject *parent)
 {
 }
 
-void LsColJob::setProperties(QList<QByteArray> properties)
+void LsColJob::setProperties(const QList<QByteArray> &properties)
 {
     _properties = properties;
 }
@@ -332,42 +332,9 @@ QList<QByteArray> LsColJob::properties() const
 
 void LsColJob::start()
 {
-    QList<QByteArray> properties = _properties;
-
-    if (properties.isEmpty()) {
-        qCWarning(lcLsColJob) << "Propfind with no properties!";
-    }
-    QByteArray propStr;
-    foreach (const QByteArray &prop, properties) {
-        if (prop.contains(':')) {
-            int colIdx = prop.lastIndexOf(":");
-            auto ns = prop.left(colIdx);
-            if (ns == "http://owncloud.org/ns") {
-                propStr += "    <oc:" + prop.mid(colIdx + 1) + " />\n";
-            } else {
-                propStr += "    <" + prop.mid(colIdx + 1) + " xmlns=\"" + ns + "\" />\n";
-            }
-        } else {
-            propStr += "    <d:" + prop + " />\n";
-        }
-    }
-
     QNetworkRequest req;
-    req.setRawHeader("Depth", "1");
-    QByteArray xml("<?xml version=\"1.0\" ?>\n"
-                   "<d:propfind xmlns:d=\"DAV:\" xmlns:oc=\"http://owncloud.org/ns\">\n"
-                   "  <d:prop>\n"
-        + propStr + "  </d:prop>\n"
-                    "</d:propfind>\n");
-    QBuffer *buf = new QBuffer(this);
-    buf->setData(xml);
-    buf->open(QIODevice::ReadOnly);
-    if (_url.isValid()) {
-        sendRequest("PROPFIND", _url, req, buf);
-    } else {
-        sendRequest("PROPFIND", makeDavUrl(path()), req, buf);
-    }
-    AbstractNetworkJob::start();
+    req.setRawHeader(QByteArrayLiteral("Depth"), QByteArrayLiteral("1"));
+    startImpl(req);
 }
 
 // TODO: Instead of doing all in this slot, we should iteratively parse in readyRead(). This
@@ -407,29 +374,71 @@ bool LsColJob::finished()
     return true;
 }
 
-/*********************************************************************************************/
+void LsColJob::startImpl(const QNetworkRequest &req)
+{
+    if (_properties.isEmpty()) {
+        qCWarning(lcLsColJob) << "Propfind with no properties!";
+    }
+    QByteArray data;
+    {
+        QTextStream stream(&data, QIODevice::WriteOnly);
+        stream.setCodec("UTF-8");
+        stream << QByteArrayLiteral("<?xml version=\"1.0\" encoding=\"utf-8\"?>"
+                                    "<d:propfind xmlns:d=\"DAV:\">"
+                                    "<d:prop>");
 
-namespace {
-    const QString statusphpC() { return QStringLiteral("status.php"); }
-    const QString owncloudDirC() { return QStringLiteral("owncloud/"); }
+        for (const QByteArray &prop : qAsConst(_properties)) {
+            const int colIdx = prop.lastIndexOf(':');
+            if (colIdx >= 0) {
+                stream << QByteArrayLiteral("<") << prop.mid(colIdx + 1) << QByteArrayLiteral(" xmlns=\"") << prop.left(colIdx) << QByteArrayLiteral("\"/>");
+            } else {
+                stream << QByteArrayLiteral("<d:") << prop << QByteArrayLiteral("/>");
+            }
+        }
+        stream << QByteArrayLiteral("</d:prop>M"
+                                    "</d:propfind>\n");
+    }
+
+    QBuffer *buf = new QBuffer(this);
+    buf->setData(data);
+    buf->open(QIODevice::ReadOnly);
+    sendRequest(QByteArrayLiteral("PROPFIND"), _url, req, buf);
+    AbstractNetworkJob::start();
 }
 
+const QHash<QString, qint64> &LsColJob::sizes() const
+{
+    return _sizes;
+}
+
+/*********************************************************************************************/
+
 CheckServerJob::CheckServerJob(AccountPtr account, QObject *parent)
-    : AbstractNetworkJob(account, statusphpC(), parent)
+    : AbstractNetworkJob(account, QStringLiteral("status.php"), parent)
     , _subdirFallback(false)
-    , _permanentRedirects(0)
 {
     setIgnoreCredentialFailure(true);
-    connect(this, &AbstractNetworkJob::redirected,
-        this, &CheckServerJob::slotRedirected);
+    setAuthenticationJob(true);
 }
 
 void CheckServerJob::start()
 {
     _serverUrl = account()->url();
-    sendRequest("GET", Utility::concatUrlPath(_serverUrl, path()));
+    QNetworkRequest req;
+    // don't authenticate the request to a possibly external service
+    req.setAttribute(HttpCredentials::DontAddCredentialsAttribute, true);
+    req.setAttribute(QNetworkRequest::RedirectPolicyAttribute, QNetworkRequest::NoLessSafeRedirectPolicy);
+    req.setRawHeader(QByteArrayLiteral("OC-Connection-Validator"), QByteArrayLiteral("desktop"));
+    req.setMaximumRedirectsAllowed(_maxRedirectsAllowed);
+    sendRequest("GET", Utility::concatUrlPath(_serverUrl, path()), req);
     connect(reply(), &QNetworkReply::metaDataChanged, this, &CheckServerJob::metaDataChangedSlot);
     connect(reply(), &QNetworkReply::encrypted, this, &CheckServerJob::encryptedSlot);
+    connect(reply(), &QNetworkReply::redirected, this, [this] {
+        const auto code = reply()->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
+        if (code == 302 || code == 307) {
+            _redirectDistinct = false;
+        }
+    });
     AbstractNetworkJob::start();
 }
 
@@ -441,7 +450,7 @@ void CheckServerJob::onTimedOut()
     } else if (!reply()) {
         qCWarning(lcCheckServerJob) << "Timeout even there was no reply?";
     }
-    deleteLater();
+    AbstractNetworkJob::onTimedOut();
 }
 
 QString CheckServerJob::version(const QJsonObject &info)
@@ -477,21 +486,14 @@ void CheckServerJob::encryptedSlot()
     mergeSslConfigurationForSslButton(reply()->sslConfiguration(), account());
 }
 
-void CheckServerJob::slotRedirected(QNetworkReply *reply, const QUrl &targetUrl, int redirectCount)
+int CheckServerJob::maxRedirectsAllowed() const
 {
-    const auto slashStatusPhp = QStringLiteral("/%1").arg(statusphpC());
+    return _maxRedirectsAllowed;
+}
 
-    int httpCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
-    QString path = targetUrl.path();
-    if ((httpCode == 301 || httpCode == 308) // permanent redirection
-        && redirectCount == _permanentRedirects // don't apply permanent redirects after a temporary one
-        && path.endsWith(slashStatusPhp)) {
-        _serverUrl = targetUrl;
-        _serverUrl.setPath(path.left(path.size() - slashStatusPhp.size()));
-        qCInfo(lcCheckServerJob) << "status.php was permanently redirected to"
-                                 << targetUrl << "new server url is" << _serverUrl;
-        ++_permanentRedirects;
-    }
+void CheckServerJob::setMaxRedirectsAllowed(int maxRedirectsAllowed)
+{
+    _maxRedirectsAllowed = maxRedirectsAllowed;
 }
 
 void CheckServerJob::metaDataChangedSlot()
@@ -500,33 +502,43 @@ void CheckServerJob::metaDataChangedSlot()
     mergeSslConfigurationForSslButton(reply()->sslConfiguration(), account());
 }
 
-
 bool CheckServerJob::finished()
 {
-    if (reply()->request().url().scheme() == QLatin1String("https")
+    const QUrl targetUrl = reply()->url().adjusted(QUrl::RemoveFilename);
+    if (targetUrl.scheme() == QLatin1String("https")
         && reply()->sslConfiguration().sessionTicket().isEmpty()
         && reply()->error() == QNetworkReply::NoError) {
         qCWarning(lcCheckServerJob) << "No SSL session identifier / session ticket is used, this might impact sync performance negatively.";
     }
+    if (_serverUrl != targetUrl) {
+        if (_redirectDistinct) {
+            _serverUrl = targetUrl;
+        } else {
+            if (_firstTry) {
+                qCWarning(lcCheckServerJob) << "Server might have moved, retry";
+                _firstTry = false;
+                _redirectDistinct = true;
+                start();
+                return false;
+            } else {
+                qCWarning(lcCheckServerJob) << "We got a temporary moved server aborting";
+                emit instanceNotFound(reply());
+                return true;
+            }
+        }
+    }
 
     mergeSslConfigurationForSslButton(reply()->sslConfiguration(), account());
 
-    // The server installs to /owncloud. Let's try that if the file wasn't found
-    // at the original location
-    if ((reply()->error() == QNetworkReply::ContentNotFoundError) && (!_subdirFallback)) {
-        _subdirFallback = true;
-        setPath(owncloudDirC() + statusphpC());
-        start();
-        qCInfo(lcCheckServerJob) << "Retrying with" << reply()->url();
-        return false;
-    }
-
-    QByteArray body = reply()->peek(4 * 1024);
-    int httpStatus = reply()->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
-    if (body.isEmpty() || httpStatus != 200) {
-        qCWarning(lcCheckServerJob) << "error: status.php replied " << httpStatus << body;
+    const int httpStatus = reply()->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
+    if (reply()->error() == QNetworkReply::TooManyRedirectsError) {
+        qCWarning(lcCheckServerJob) << "error:" << reply()->errorString();
+        emit instanceNotFound(reply());
+    } else if (httpStatus != 200 || reply()->bytesAvailable() == 0) {
+        qCWarning(lcCheckServerJob) << "error: status.php replied " << httpStatus;
         emit instanceNotFound(reply());
     } else {
+        const QByteArray body = reply()->peek(4 * 1024);
         QJsonParseError error;
         auto status = QJsonDocument::fromJson(body, &error);
         // empty or invalid response
@@ -547,100 +559,23 @@ bool CheckServerJob::finished()
 
 /*********************************************************************************************/
 
-PropfindJob::PropfindJob(AccountPtr account, const QString &path, QObject *parent)
-    : AbstractNetworkJob(account, path, parent)
-{
-}
 
 void PropfindJob::start()
 {
-    QList<QByteArray> properties = _properties;
-
-    if (properties.isEmpty()) {
-        qCWarning(lcLsColJob) << "Propfind with no properties!";
-    }
+    connect(this, &LsColJob::directoryListingIterated, this, [this](const QString &, const QMap<QString, QString> &values) {
+        OC_ASSERT(!_done);
+        _done = true;
+        Q_EMIT result(values);
+    });
     QNetworkRequest req;
     // Always have a higher priority than the propagator because we use this from the UI
     // and really want this to be done first (no matter what internal scheduling QNAM uses).
     // Also possibly useful for avoiding false timeouts.
     req.setPriority(QNetworkRequest::HighPriority);
-    req.setRawHeader("Depth", "0");
-    QByteArray propStr;
-    foreach (const QByteArray &prop, properties) {
-        if (prop.contains(':')) {
-            int colIdx = prop.lastIndexOf(":");
-            propStr += "    <" + prop.mid(colIdx + 1) + " xmlns=\"" + prop.left(colIdx) + "\" />\n";
-        } else {
-            propStr += "    <d:" + prop + " />\n";
-        }
-    }
-    QByteArray xml = "<?xml version=\"1.0\" ?>\n"
-                     "<d:propfind xmlns:d=\"DAV:\">\n"
-                     "  <d:prop>\n"
-        + propStr + "  </d:prop>\n"
-                    "</d:propfind>\n";
-
-    QBuffer *buf = new QBuffer(this);
-    buf->setData(xml);
-    buf->open(QIODevice::ReadOnly);
-    sendRequest("PROPFIND", makeDavUrl(path()), req, buf);
-    AbstractNetworkJob::start();
+    req.setRawHeader(QByteArrayLiteral("Depth"), QByteArrayLiteral("0"));
+    startImpl(req);
 }
 
-void PropfindJob::setProperties(QList<QByteArray> properties)
-{
-    _properties = properties;
-}
-
-QList<QByteArray> PropfindJob::properties() const
-{
-    return _properties;
-}
-
-bool PropfindJob::finished()
-{
-    qCInfo(lcPropfindJob) << "PROPFIND of" << reply()->request().url() << "FINISHED WITH STATUS"
-                          << replyStatusString();
-
-    int http_result_code = reply()->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
-
-    if (http_result_code == 207) {
-        // Parse DAV response
-        QXmlStreamReader reader(reply());
-        reader.addExtraNamespaceDeclaration(QXmlStreamNamespaceDeclaration(QStringLiteral("d"), QStringLiteral("DAV:")));
-
-        QVariantMap items;
-        // introduced to nesting is ignored
-        QStack<QString> curElement;
-
-        while (!reader.atEnd()) {
-            QXmlStreamReader::TokenType type = reader.readNext();
-            if (type == QXmlStreamReader::StartElement) {
-                if (!curElement.isEmpty() && curElement.top() == QLatin1String("prop")) {
-                    items.insert(reader.name().toString(), reader.readElementText(QXmlStreamReader::SkipChildElements));
-                } else {
-                    curElement.push(reader.name().toString());
-                }
-            }
-            if (type == QXmlStreamReader::EndElement) {
-                if (curElement.top() == reader.name()) {
-                    curElement.pop();
-                }
-            }
-        }
-        if (reader.hasError()) {
-            qCWarning(lcPropfindJob) << "XML parser error: " << reader.errorString();
-            emit finishedWithError(reply());
-        } else {
-            emit result(items);
-        }
-    } else {
-        qCWarning(lcPropfindJob) << "*not* successful, http result code is" << http_result_code
-                                 << (http_result_code == 302 ? reply()->header(QNetworkRequest::LocationHeader).toString() : QLatin1String(""));
-        emit finishedWithError(reply());
-    }
-    return true;
-}
 
 /*********************************************************************************************/
 
@@ -829,7 +764,7 @@ bool JsonApiJob::finished()
     int statusCode = 0;
 
     if (reply()->error() != QNetworkReply::NoError) {
-        qCWarning(lcJsonApiJob) << "Network error: " << path() << errorString() << reply()->attribute(QNetworkRequest::HttpStatusCodeAttribute);
+        qCWarning(lcJsonApiJob) << "Network error: " << this << errorString() << reply()->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
         emit jsonReceived(QJsonDocument(), statusCode);
         return true;
     }
@@ -864,9 +799,10 @@ bool JsonApiJob::finished()
 }
 
 DetermineAuthTypeJob::DetermineAuthTypeJob(AccountPtr account, QObject *parent)
-    : QObject(parent)
-    , _account(account)
+    : AbstractNetworkJob(account, QString(), parent)
 {
+    setAuthenticationJob(true);
+    setIgnoreCredentialFailure(true);
 }
 
 void DetermineAuthTypeJob::start()
@@ -878,22 +814,22 @@ void DetermineAuthTypeJob::start()
     req.setAttribute(HttpCredentials::DontAddCredentialsAttribute, true);
     // Don't reuse previous auth credentials
     req.setAttribute(QNetworkRequest::AuthenticationReuseAttribute, QNetworkRequest::Manual);
+    sendRequest("PROPFIND", _account->davUrl(), req);
+    AbstractNetworkJob::start();
+}
 
-    auto propfind = _account->sendRequest("PROPFIND", _account->davUrl(), req);
-    propfind->setTimeout(30 * 1000);
-    propfind->setIgnoreCredentialFailure(true);
-    connect(propfind, &SimpleNetworkJob::finishedSignal, this, [this](QNetworkReply *reply) {
-        auto authChallenge = reply->rawHeader("WWW-Authenticate").toLower();
-        auto result = AuthType::Basic;
-        if (authChallenge.contains("bearer ")) {
-            result = AuthType::OAuth;
-        } else if (authChallenge.isEmpty()) {
-            qCWarning(lcDetermineAuthTypeJob) << "Did not receive WWW-Authenticate reply to auth-test PROPFIND";
-        }
-        qCInfo(lcDetermineAuthTypeJob) << "Auth type for" << _account->davUrl() << "is" << result;
-        emit this->authType(result);
-        this->deleteLater();
-    });
+bool DetermineAuthTypeJob::finished()
+{
+    auto authChallenge = reply()->rawHeader("WWW-Authenticate").toLower();
+    auto result = AuthType::Basic;
+    if (authChallenge.contains("bearer ")) {
+        result = AuthType::OAuth;
+    } else if (authChallenge.isEmpty()) {
+        qCWarning(lcDetermineAuthTypeJob) << "Did not receive WWW-Authenticate reply to auth-test PROPFIND";
+    }
+    qCInfo(lcDetermineAuthTypeJob) << "Auth type for" << _account->davUrl() << "is" << result;
+    emit this->authType(result);
+    return true;
 }
 
 SimpleNetworkJob::SimpleNetworkJob(AccountPtr account, QObject *parent)
@@ -901,12 +837,39 @@ SimpleNetworkJob::SimpleNetworkJob(AccountPtr account, QObject *parent)
 {
 }
 
-QNetworkReply *SimpleNetworkJob::startRequest(const QByteArray &verb, const QUrl &url,
-    QNetworkRequest req, QIODevice *requestBody)
+void SimpleNetworkJob::start()
 {
-    auto reply = sendRequest(verb, url, req, requestBody);
-    start();
-    return reply;
+    sendRequest(_simpleVerb, _simpleUrl, _simpleRequest, _simpleBody);
+    AbstractNetworkJob::start();
+}
+
+void SimpleNetworkJob::prepareRequest(const QByteArray &verb, const QUrl &url,
+    const QNetworkRequest &req, QIODevice *requestBody)
+{
+    _simpleVerb = verb;
+    _simpleUrl = url;
+    _simpleRequest = req;
+    _simpleBody = requestBody;
+}
+
+void SimpleNetworkJob::prepareRequest(const QByteArray &verb, const QUrl &url, const QNetworkRequest &req, const QUrlQuery &arguments)
+{
+    // not a leak
+    auto requestBody = new QBuffer {};
+    requestBody->setData(arguments.query(QUrl::FullyEncoded).toUtf8());
+    auto newReq = req;
+    newReq.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded; charset=UTF-8"));
+    return prepareRequest(verb, url, newReq, requestBody);
+}
+
+void SimpleNetworkJob::prepareRequest(const QByteArray &verb, const QUrl &url, const QNetworkRequest &req, const QJsonObject &arguments)
+{
+    // not a leak
+    auto requestBody = new QBuffer {};
+    requestBody->setData(QJsonDocument(arguments).toJson());
+    auto newReq = req;
+    newReq.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/json"));
+    return prepareRequest(verb, url, newReq, requestBody);
 }
 
 bool SimpleNetworkJob::finished()
@@ -915,35 +878,19 @@ bool SimpleNetworkJob::finished()
     return true;
 }
 
-void fetchPrivateLinkUrl(AccountPtr account, const QString &remotePath,
-    const QByteArray &numericFileId, QObject *target,
+void fetchPrivateLinkUrl(AccountPtr account, const QString &remotePath, QObject *target,
     std::function<void(const QString &url)> targetFun)
 {
-    QString oldUrl;
-    if (!numericFileId.isEmpty())
-        oldUrl = account->deprecatedPrivateLinkUrl(numericFileId).toString(QUrl::FullyEncoded);
-
     // Retrieve the new link by PROPFIND
     PropfindJob *job = new PropfindJob(account, remotePath, target);
-    job->setProperties(
-        QList<QByteArray>()
-        << "http://owncloud.org/ns:fileid" // numeric file id for fallback private link generation
-        << "http://owncloud.org/ns:privatelink");
+    job->setProperties({ QByteArrayLiteral("http://owncloud.org/ns:privatelink") });
     job->setTimeout(10 * 1000);
-    QObject::connect(job, &PropfindJob::result, target, [=](const QVariantMap &result) {
-        auto privateLinkUrl = result[QStringLiteral("privatelink")].toString();
-        auto numericFileId = result[QStringLiteral("fileid")].toByteArray();
+    QObject::connect(job, &PropfindJob::result, target, [=](const QMap<QString, QString> &result) {
+        auto privateLinkUrl = result[QStringLiteral("privatelink")];
         if (!privateLinkUrl.isEmpty()) {
             targetFun(privateLinkUrl);
-        } else if (!numericFileId.isEmpty()) {
-            targetFun(account->deprecatedPrivateLinkUrl(numericFileId).toString(QUrl::FullyEncoded));
-        } else {
-            targetFun(oldUrl);
         }
     });
-    QObject::connect(job, &PropfindJob::finishedWithError, target, [=](QNetworkReply *) {
-        targetFun(oldUrl);
-    });
     job->start();
 }
 
