@@ -678,4 +678,14 @@ bool Theme::connectionValidatorClearCookies() const
     return false;
 }
 
+bool Theme::enableSocketApiIconSupport() const
+{
+    return true;
+}
+
+bool Theme::warnOnMultipleDb() const
+{
+    return isVanilla();
+}
+
 } // end namespace client
