@@ -51,8 +51,10 @@ void VfsSuffix::startImpl(const VfsSetupParams &params)
         if (!rec.isVirtualFile() && rec._path.endsWith(APPLICATION_DOTVIRTUALFILE_SUFFIX))
             toWipe.append(rec._path);
     });
-    for (const auto &path : toWipe)
+    for (const auto &path : toWipe) {
         params.journal->deleteFileRecord(QString::fromUtf8(path));
+    }
+    Q_EMIT started();
 }
 
 void VfsSuffix::stop()
@@ -77,11 +79,8 @@ Result<Vfs::ConvertToPlaceholderResult, QString> VfsSuffix::updateMetadata(const
 Result<void, QString> VfsSuffix::createPlaceholder(const SyncFileItem &item)
 {
     // The concrete shape of the placeholder is also used in isDehydratedPlaceholder() below
-    QString fn = _setupParams.filesystemPath + item._file;
-    if (!fn.endsWith(fileSuffix())) {
-        OC_ASSERT_X(false, "vfs file isn't ending with suffix");
-        return QStringLiteral("vfs file isn't ending with suffix");
-    }
+    const QString fn = _setupParams.filesystemPath + item._file;
+    Q_ASSERT(fn.endsWith(fileSuffix()));
 
     QFile file(fn);
     if (file.exists() && file.size() > 1
@@ -146,4 +145,14 @@ Vfs::AvailabilityResult VfsSuffix::availability(const QString &folderPath)
     return availabilityInDb(folderPath);
 }
 
+QString VfsSuffix::underlyingFileName(const QString &fileName) const
+{
+    {
+        if (fileName.endsWith(fileSuffix())) {
+            return fileName.chopped(fileSuffix().size());
+        }
+        return fileName;
+    }
+}
+
 } // namespace OCC
